from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.SelectMgr import *
from OCC.Core.Prs3d import *
from OCC.Core.TopoDS import *
from OCC.Core.PrsMgr import *
from OCC.Core.TopLoc import *
from OCC.Core.V3d import *
from OCC.Core.Select3D import *
from OCC.Core.TopAbs import *


class StdSelect_TypeOfFace(IntEnum):
	StdSelect_AnyFace: int = ...
	StdSelect_Plane: int = ...
	StdSelect_Cylinder: int = ...
	StdSelect_Sphere: int = ...
	StdSelect_Torus: int = ...
	StdSelect_Revol: int = ...
	StdSelect_Cone: int = ...
StdSelect_AnyFace = StdSelect_TypeOfFace.StdSelect_AnyFace
StdSelect_Plane = StdSelect_TypeOfFace.StdSelect_Plane
StdSelect_Cylinder = StdSelect_TypeOfFace.StdSelect_Cylinder
StdSelect_Sphere = StdSelect_TypeOfFace.StdSelect_Sphere
StdSelect_Torus = StdSelect_TypeOfFace.StdSelect_Torus
StdSelect_Revol = StdSelect_TypeOfFace.StdSelect_Revol
StdSelect_Cone = StdSelect_TypeOfFace.StdSelect_Cone

class StdSelect_TypeOfEdge(IntEnum):
	StdSelect_AnyEdge: int = ...
	StdSelect_Line: int = ...
	StdSelect_Circle: int = ...
StdSelect_AnyEdge = StdSelect_TypeOfEdge.StdSelect_AnyEdge
StdSelect_Line = StdSelect_TypeOfEdge.StdSelect_Line
StdSelect_Circle = StdSelect_TypeOfEdge.StdSelect_Circle

class StdSelect_TypeOfSelectionImage(IntEnum):
	StdSelect_TypeOfSelectionImage_NormalizedDepth: int = ...
	StdSelect_TypeOfSelectionImage_NormalizedDepthInverted: int = ...
	StdSelect_TypeOfSelectionImage_UnnormalizedDepth: int = ...
	StdSelect_TypeOfSelectionImage_ColoredDetectedObject: int = ...
	StdSelect_TypeOfSelectionImage_ColoredEntity: int = ...
	StdSelect_TypeOfSelectionImage_ColoredOwner: int = ...
	StdSelect_TypeOfSelectionImage_ColoredSelectionMode: int = ...
StdSelect_TypeOfSelectionImage_NormalizedDepth = StdSelect_TypeOfSelectionImage.StdSelect_TypeOfSelectionImage_NormalizedDepth
StdSelect_TypeOfSelectionImage_NormalizedDepthInverted = StdSelect_TypeOfSelectionImage.StdSelect_TypeOfSelectionImage_NormalizedDepthInverted
StdSelect_TypeOfSelectionImage_UnnormalizedDepth = StdSelect_TypeOfSelectionImage.StdSelect_TypeOfSelectionImage_UnnormalizedDepth
StdSelect_TypeOfSelectionImage_ColoredDetectedObject = StdSelect_TypeOfSelectionImage.StdSelect_TypeOfSelectionImage_ColoredDetectedObject
StdSelect_TypeOfSelectionImage_ColoredEntity = StdSelect_TypeOfSelectionImage.StdSelect_TypeOfSelectionImage_ColoredEntity
StdSelect_TypeOfSelectionImage_ColoredOwner = StdSelect_TypeOfSelectionImage.StdSelect_TypeOfSelectionImage_ColoredOwner
StdSelect_TypeOfSelectionImage_ColoredSelectionMode = StdSelect_TypeOfSelectionImage.StdSelect_TypeOfSelectionImage_ColoredSelectionMode

class stdselect:
	@staticmethod
	def SetDrawerForBRepOwner(aSelection: SelectMgr_Selection, aDrawer: Prs3d_Drawer) -> None: ...

class StdSelect_BRepOwner(SelectMgr_EntityOwner):
	@overload
	def __init__(self, aPriority: int) -> None: ...
	@overload
	def __init__(self, aShape: TopoDS_Shape, aPriority: Optional[int] = 0, ComesFromDecomposition: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, aShape: TopoDS_Shape, theOrigin: SelectMgr_SelectableObject, aPriority: Optional[int] = 0, FromDecomposition: Optional[bool] = False) -> None: ...
	def Clear(self, aPM: PrsMgr_PresentationManager, aMode: Optional[int] = 0) -> None: ...
	def HasHilightMode(self) -> bool: ...
	def HasShape(self) -> bool: ...
	def HilightMode(self) -> int: ...
	def HilightWithColor(self, thePM: PrsMgr_PresentationManager3d, theStyle: Prs3d_Drawer, theMode: Optional[int] = 0) -> None: ...
	def IsHilighted(self, aPM: PrsMgr_PresentationManager, aMode: Optional[int] = 0) -> bool: ...
	def ResetHilightMode(self) -> None: ...
	def SetHilightMode(self, theMode: int) -> None: ...
	def SetLocation(self, aLoc: TopLoc_Location) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...
	def Unhilight(self, aPM: PrsMgr_PresentationManager, aMode: Optional[int] = 0) -> None: ...
	def UpdateHighlightTrsf(self, theViewer: V3d_Viewer, theManager: PrsMgr_PresentationManager3d, theDispMode: int) -> None: ...

class StdSelect_BRepSelectionTool:
	@staticmethod
	def ComputeSensitive(theShape: TopoDS_Shape, theOwner: SelectMgr_EntityOwner, theSelection: SelectMgr_Selection, theDeflection: float, theDeflAngle: float, theNbPOnEdge: int, theMaxiParam: float, theAutoTriang: Optional[bool] = True) -> None: ...
	@staticmethod
	def GetEdgeSensitive(theShape: TopoDS_Shape, theOwner: SelectMgr_EntityOwner, theSelection: SelectMgr_Selection, theDeflection: float, theDeviationAngle: float, theNbPOnEdge: int, theMaxiParam: float, theSensitive: Select3D_SensitiveEntity) -> None: ...
	@staticmethod
	def GetSensitiveForFace(theFace: TopoDS_Face, theOwner: SelectMgr_EntityOwner, theOutList: Select3D_EntitySequence, theAutoTriang: Optional[bool] = True, theNbPOnEdge: Optional[int] = 9, theMaxiParam: Optional[float] = 500, theInteriorFlag: Optional[bool] = True) -> bool: ...
	@staticmethod
	def GetStandardPriority(theShape: TopoDS_Shape, theType: TopAbs_ShapeEnum) -> int: ...
	@overload
	@staticmethod
	def Load(aSelection: SelectMgr_Selection, aShape: TopoDS_Shape, aType: TopAbs_ShapeEnum, theDeflection: float, theDeviationAngle: float, AutoTriangulation: Optional[bool] = True, aPriority: Optional[int] = -1, NbPOnEdge: Optional[int] = 9, MaximalParameter: Optional[float] = 500) -> None: ...
	@overload
	@staticmethod
	def Load(aSelection: SelectMgr_Selection, Origin: SelectMgr_SelectableObject, aShape: TopoDS_Shape, aType: TopAbs_ShapeEnum, theDeflection: float, theDeviationAngle: float, AutoTriangulation: Optional[bool] = True, aPriority: Optional[int] = -1, NbPOnEdge: Optional[int] = 9, MaximalParameter: Optional[float] = 500) -> None: ...
	@staticmethod
	def PreBuildBVH(theSelection: SelectMgr_Selection) -> None: ...

class StdSelect_EdgeFilter(SelectMgr_Filter):
	def __init__(self, Edge: StdSelect_TypeOfEdge) -> None: ...
	def ActsOn(self, aStandardMode: TopAbs_ShapeEnum) -> bool: ...
	def IsOk(self, anobj: SelectMgr_EntityOwner) -> bool: ...
	def SetType(self, aNewType: StdSelect_TypeOfEdge) -> None: ...
	def Type(self) -> StdSelect_TypeOfEdge: ...

class StdSelect_FaceFilter(SelectMgr_Filter):
	def __init__(self, aTypeOfFace: StdSelect_TypeOfFace) -> None: ...
	def ActsOn(self, aStandardMode: TopAbs_ShapeEnum) -> bool: ...
	def IsOk(self, anobj: SelectMgr_EntityOwner) -> bool: ...
	def SetType(self, aNewType: StdSelect_TypeOfFace) -> None: ...
	def Type(self) -> StdSelect_TypeOfFace: ...

class StdSelect_Shape(PrsMgr_PresentableObject):
	def __init__(self, theShape: TopoDS_Shape, theDrawer: Optional[Prs3d_Drawer] = Prs3d_Drawer()) -> None: ...
	def Compute(self, aPresentationManager: PrsMgr_PresentationManager3d, aPresentation: Prs3d_Presentation, aMode: Optional[int] = 0) -> None: ...
	@overload
	def Shape(self) -> TopoDS_Shape: ...
	@overload
	def Shape(self, theShape: TopoDS_Shape) -> None: ...

class StdSelect_ShapeTypeFilter(SelectMgr_Filter):
	def __init__(self, aType: TopAbs_ShapeEnum) -> None: ...
	def ActsOn(self, aStandardMode: TopAbs_ShapeEnum) -> bool: ...
	def IsOk(self, anobj: SelectMgr_EntityOwner) -> bool: ...
	def Type(self) -> TopAbs_ShapeEnum: ...

# harray1 classes
# harray2 classes
# hsequence classes

stdselect_SetDrawerForBRepOwner = stdselect.SetDrawerForBRepOwner
StdSelect_BRepSelectionTool_ComputeSensitive = StdSelect_BRepSelectionTool.ComputeSensitive
StdSelect_BRepSelectionTool_GetEdgeSensitive = StdSelect_BRepSelectionTool.GetEdgeSensitive
StdSelect_BRepSelectionTool_GetSensitiveForFace = StdSelect_BRepSelectionTool.GetSensitiveForFace
StdSelect_BRepSelectionTool_GetStandardPriority = StdSelect_BRepSelectionTool.GetStandardPriority
StdSelect_BRepSelectionTool_Load = StdSelect_BRepSelectionTool.Load
StdSelect_BRepSelectionTool_Load = StdSelect_BRepSelectionTool.Load
StdSelect_BRepSelectionTool_PreBuildBVH = StdSelect_BRepSelectionTool.PreBuildBVH



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *


class Intrv_SequenceOfInterval:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Intrv_Interval: ...
    def Last(self) -> Intrv_Interval: ...
    def Length(self) -> int: ...
    def Append(self, theItem: Intrv_Interval) -> Intrv_Interval: ...
    def Prepend(self, theItem: Intrv_Interval) -> Intrv_Interval: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Intrv_Interval: ...
    def SetValue(self, theIndex: int, theValue: Intrv_Interval) -> None: ...

class Intrv_Position(IntEnum):
	Intrv_Before: int = ...
	Intrv_JustBefore: int = ...
	Intrv_OverlappingAtStart: int = ...
	Intrv_JustEnclosingAtEnd: int = ...
	Intrv_Enclosing: int = ...
	Intrv_JustOverlappingAtStart: int = ...
	Intrv_Similar: int = ...
	Intrv_JustEnclosingAtStart: int = ...
	Intrv_Inside: int = ...
	Intrv_JustOverlappingAtEnd: int = ...
	Intrv_OverlappingAtEnd: int = ...
	Intrv_JustAfter: int = ...
	Intrv_After: int = ...
Intrv_Before = Intrv_Position.Intrv_Before
Intrv_JustBefore = Intrv_Position.Intrv_JustBefore
Intrv_OverlappingAtStart = Intrv_Position.Intrv_OverlappingAtStart
Intrv_JustEnclosingAtEnd = Intrv_Position.Intrv_JustEnclosingAtEnd
Intrv_Enclosing = Intrv_Position.Intrv_Enclosing
Intrv_JustOverlappingAtStart = Intrv_Position.Intrv_JustOverlappingAtStart
Intrv_Similar = Intrv_Position.Intrv_Similar
Intrv_JustEnclosingAtStart = Intrv_Position.Intrv_JustEnclosingAtStart
Intrv_Inside = Intrv_Position.Intrv_Inside
Intrv_JustOverlappingAtEnd = Intrv_Position.Intrv_JustOverlappingAtEnd
Intrv_OverlappingAtEnd = Intrv_Position.Intrv_OverlappingAtEnd
Intrv_JustAfter = Intrv_Position.Intrv_JustAfter
Intrv_After = Intrv_Position.Intrv_After

class Intrv_Interval:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Start: float, End: float) -> None: ...
	@overload
	def __init__(self, Start: float, TolStart: float, End: float, TolEnd: float) -> None: ...
	def Bounds(self, TolStart: float, TolEnd: float) -> Tuple[float, float]: ...
	def CutAtEnd(self, End: float, TolEnd: float) -> None: ...
	def CutAtStart(self, Start: float, TolStart: float) -> None: ...
	def End(self) -> float: ...
	def FuseAtEnd(self, End: float, TolEnd: float) -> None: ...
	def FuseAtStart(self, Start: float, TolStart: float) -> None: ...
	def IsAfter(self, Other: Intrv_Interval) -> bool: ...
	def IsBefore(self, Other: Intrv_Interval) -> bool: ...
	def IsEnclosing(self, Other: Intrv_Interval) -> bool: ...
	def IsInside(self, Other: Intrv_Interval) -> bool: ...
	def IsJustAfter(self, Other: Intrv_Interval) -> bool: ...
	def IsJustBefore(self, Other: Intrv_Interval) -> bool: ...
	def IsJustEnclosingAtEnd(self, Other: Intrv_Interval) -> bool: ...
	def IsJustEnclosingAtStart(self, Other: Intrv_Interval) -> bool: ...
	def IsJustOverlappingAtEnd(self, Other: Intrv_Interval) -> bool: ...
	def IsJustOverlappingAtStart(self, Other: Intrv_Interval) -> bool: ...
	def IsOverlappingAtEnd(self, Other: Intrv_Interval) -> bool: ...
	def IsOverlappingAtStart(self, Other: Intrv_Interval) -> bool: ...
	def IsProbablyEmpty(self) -> bool: ...
	def IsSimilar(self, Other: Intrv_Interval) -> bool: ...
	def Position(self, Other: Intrv_Interval) -> Intrv_Position: ...
	def SetEnd(self, End: float, TolEnd: float) -> None: ...
	def SetStart(self, Start: float, TolStart: float) -> None: ...
	def Start(self) -> float: ...
	def TolEnd(self) -> float: ...
	def TolStart(self) -> float: ...

class Intrv_Intervals:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Int: Intrv_Interval) -> None: ...
	@overload
	def Intersect(self, Tool: Intrv_Interval) -> None: ...
	@overload
	def Intersect(self, Tool: Intrv_Intervals) -> None: ...
	def NbIntervals(self) -> int: ...
	@overload
	def Subtract(self, Tool: Intrv_Interval) -> None: ...
	@overload
	def Subtract(self, Tool: Intrv_Intervals) -> None: ...
	@overload
	def Unite(self, Tool: Intrv_Interval) -> None: ...
	@overload
	def Unite(self, Tool: Intrv_Intervals) -> None: ...
	def Value(self, Index: int) -> Intrv_Interval: ...
	@overload
	def XUnite(self, Tool: Intrv_Interval) -> None: ...
	@overload
	def XUnite(self, Tool: Intrv_Intervals) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *

TCollection_MapNodePtr = NewType('TCollection_MapNodePtr', TCollection_MapNode)
TCollection_SeqNodePtr = NewType('TCollection_SeqNodePtr', TCollection_SeqNode)

class TCollection_Side(IntEnum):
	TCollection_Left: int = ...
	TCollection_Right: int = ...
TCollection_Left = TCollection_Side.TCollection_Left
TCollection_Right = TCollection_Side.TCollection_Right

class tcollection:
	@staticmethod
	def NextPrimeForMap(I: int) -> int: ...

class TCollection_AsciiString:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, message: str) -> None: ...
	@overload
	def __init__(self, message: str, aLen: int) -> None: ...
	@overload
	def __init__(self, aChar: str) -> None: ...
	@overload
	def __init__(self, length: int, filler: str) -> None: ...
	@overload
	def __init__(self, value: int) -> None: ...
	@overload
	def __init__(self, value: float) -> None: ...
	@overload
	def __init__(self, astring: TCollection_AsciiString) -> None: ...
	@overload
	def __init__(self, theOther: TCollection_AsciiString) -> None: ...
	@overload
	def __init__(self, astring: TCollection_AsciiString, message: str) -> None: ...
	@overload
	def __init__(self, astring: TCollection_AsciiString, message: str) -> None: ...
	@overload
	def __init__(self, astring: TCollection_AsciiString, message: TCollection_AsciiString) -> None: ...
	@overload
	def __init__(self, astring: TCollection_ExtendedString, replaceNonAscii: Optional[str] = 0) -> None: ...
	@overload
	def __init__(self, theStringUtf: Standard_WideChar) -> None: ...
	@overload
	def AssignCat(self, other: str) -> None: ...
	@overload
	def AssignCat(self, other: int) -> None: ...
	@overload
	def AssignCat(self, other: float) -> None: ...
	@overload
	def AssignCat(self, other: str) -> None: ...
	@overload
	def AssignCat(self, other: TCollection_AsciiString) -> None: ...
	def Capitalize(self) -> None: ...
	@overload
	def Cat(self, other: str) -> TCollection_AsciiString: ...
	@overload
	def Cat(self, other: int) -> TCollection_AsciiString: ...
	@overload
	def Cat(self, other: float) -> TCollection_AsciiString: ...
	@overload
	def Cat(self, other: str) -> TCollection_AsciiString: ...
	@overload
	def Cat(self, other: TCollection_AsciiString) -> TCollection_AsciiString: ...
	def Center(self, Width: int, Filler: str) -> None: ...
	def ChangeAll(self, aChar: str, NewChar: str, CaseSensitive: Optional[bool] = True) -> None: ...
	def Clear(self) -> None: ...
	@overload
	def Copy(self, fromwhere: str) -> None: ...
	@overload
	def Copy(self, fromwhere: TCollection_AsciiString) -> None: ...
	def EndsWith(self, theEndString: TCollection_AsciiString) -> bool: ...
	def FirstLocationInSet(self, Set: TCollection_AsciiString, FromIndex: int, ToIndex: int) -> int: ...
	def FirstLocationNotInSet(self, Set: TCollection_AsciiString, FromIndex: int, ToIndex: int) -> int: ...
	@staticmethod
	def HashCode(theAsciiString: TCollection_AsciiString, theUpperBound: int) -> int: ...
	@overload
	def Insert(self, where: int, what: str) -> None: ...
	@overload
	def Insert(self, where: int, what: str) -> None: ...
	@overload
	def Insert(self, where: int, what: TCollection_AsciiString) -> None: ...
	def InsertAfter(self, Index: int, other: TCollection_AsciiString) -> None: ...
	def InsertBefore(self, Index: int, other: TCollection_AsciiString) -> None: ...
	def IntegerValue(self) -> int: ...
	def IsAscii(self) -> bool: ...
	@overload
	def IsDifferent(self, other: str) -> bool: ...
	@overload
	def IsDifferent(self, other: TCollection_AsciiString) -> bool: ...
	def IsEmpty(self) -> bool: ...
	@overload
	def IsEqual(self, other: str) -> bool: ...
	@overload
	def IsEqual(self, other: TCollection_AsciiString) -> bool: ...
	@overload
	@staticmethod
	def IsEqual(string1: TCollection_AsciiString, string2: TCollection_AsciiString) -> bool: ...
	@overload
	@staticmethod
	def IsEqual(string1: TCollection_AsciiString, string2: str) -> bool: ...
	@overload
	def IsGreater(self, other: str) -> bool: ...
	@overload
	def IsGreater(self, other: TCollection_AsciiString) -> bool: ...
	def IsIntegerValue(self) -> bool: ...
	@overload
	def IsLess(self, other: str) -> bool: ...
	@overload
	def IsLess(self, other: TCollection_AsciiString) -> bool: ...
	def IsRealValue(self) -> bool: ...
	@staticmethod
	def IsSameString(theString1: TCollection_AsciiString, theString2: TCollection_AsciiString, theIsCaseSensitive: bool) -> bool: ...
	def LeftAdjust(self) -> None: ...
	def LeftJustify(self, Width: int, Filler: str) -> None: ...
	def Length(self) -> int: ...
	@overload
	def Location(self, other: TCollection_AsciiString, FromIndex: int, ToIndex: int) -> int: ...
	@overload
	def Location(self, N: int, C: str, FromIndex: int, ToIndex: int) -> int: ...
	def LowerCase(self) -> None: ...
	def Prepend(self, other: TCollection_AsciiString) -> None: ...
	def RealValue(self) -> float: ...
	def Remove(self, where: int, ahowmany: Optional[int] = 1) -> None: ...
	@overload
	def RemoveAll(self, C: str, CaseSensitive: bool) -> None: ...
	@overload
	def RemoveAll(self, what: str) -> None: ...
	def RightAdjust(self) -> None: ...
	def RightJustify(self, Width: int, Filler: str) -> None: ...
	@overload
	def Search(self, what: str) -> int: ...
	@overload
	def Search(self, what: TCollection_AsciiString) -> int: ...
	@overload
	def SearchFromEnd(self, what: str) -> int: ...
	@overload
	def SearchFromEnd(self, what: TCollection_AsciiString) -> int: ...
	@overload
	def SetValue(self, where: int, what: str) -> None: ...
	@overload
	def SetValue(self, where: int, what: str) -> None: ...
	@overload
	def SetValue(self, where: int, what: TCollection_AsciiString) -> None: ...
	def Split(self, where: int) -> TCollection_AsciiString: ...
	def StartsWith(self, theStartString: TCollection_AsciiString) -> bool: ...
	def SubString(self, FromIndex: int, ToIndex: int) -> TCollection_AsciiString: ...
	def Swap(self, theOther: TCollection_AsciiString) -> None: ...
	def ToCString(self) -> str: ...
	def Token(self, separators: Optional[str] = "\t", whichone: Optional[int] = 1) -> TCollection_AsciiString: ...
	def Trunc(self, ahowmany: int) -> None: ...
	def UpperCase(self) -> None: ...
	def UsefullLength(self) -> int: ...
	def Value(self, where: int) -> str: ...

class TCollection_BaseSequence:
	def Exchange(self, I: int, J: int) -> None: ...
	def IsEmpty(self) -> bool: ...
	def Length(self) -> int: ...
	def Reverse(self) -> None: ...

class TCollection_BasicMap:
	def Extent(self) -> int: ...
	def IsEmpty(self) -> bool: ...
	def NbBuckets(self) -> int: ...

class TCollection_BasicMapIterator:
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Reset(self) -> None: ...

class TCollection_ExtendedString:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, astring: str, isMultiByte: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, astring: Standard_ExtString) -> None: ...
	@overload
	def __init__(self, theStringUtf: Standard_WideChar) -> None: ...
	@overload
	def __init__(self, aChar: str) -> None: ...
	@overload
	def __init__(self, aChar: Standard_ExtCharacter) -> None: ...
	@overload
	def __init__(self, length: int, filler: Standard_ExtCharacter) -> None: ...
	@overload
	def __init__(self, value: int) -> None: ...
	@overload
	def __init__(self, value: float) -> None: ...
	@overload
	def __init__(self, astring: TCollection_ExtendedString) -> None: ...
	@overload
	def __init__(self, theOther: TCollection_ExtendedString) -> None: ...
	@overload
	def __init__(self, astring: TCollection_AsciiString, isMultiByte: Optional[bool] = True) -> None: ...
	@overload
	def AssignCat(self, other: TCollection_ExtendedString) -> None: ...
	@overload
	def AssignCat(self, theChar: Standard_Utf16Char) -> None: ...
	def Cat(self, other: TCollection_ExtendedString) -> TCollection_ExtendedString: ...
	def ChangeAll(self, aChar: Standard_ExtCharacter, NewChar: Standard_ExtCharacter) -> None: ...
	def Clear(self) -> None: ...
	def Copy(self, fromwhere: TCollection_ExtendedString) -> None: ...
	def EndsWith(self, theEndString: TCollection_ExtendedString) -> bool: ...
	@staticmethod
	def HashCode(theString: TCollection_ExtendedString, theUpperBound: int) -> int: ...
	@overload
	def Insert(self, where: int, what: Standard_ExtCharacter) -> None: ...
	@overload
	def Insert(self, where: int, what: TCollection_ExtendedString) -> None: ...
	def IsAscii(self) -> bool: ...
	@overload
	def IsDifferent(self, other: Standard_ExtString) -> bool: ...
	@overload
	def IsDifferent(self, other: TCollection_ExtendedString) -> bool: ...
	def IsEmpty(self) -> bool: ...
	@overload
	def IsEqual(self, other: Standard_ExtString) -> bool: ...
	@overload
	def IsEqual(self, other: TCollection_ExtendedString) -> bool: ...
	@overload
	@staticmethod
	def IsEqual(theString1: TCollection_ExtendedString, theString2: TCollection_ExtendedString) -> bool: ...
	@overload
	def IsGreater(self, other: Standard_ExtString) -> bool: ...
	@overload
	def IsGreater(self, other: TCollection_ExtendedString) -> bool: ...
	@overload
	def IsLess(self, other: Standard_ExtString) -> bool: ...
	@overload
	def IsLess(self, other: TCollection_ExtendedString) -> bool: ...
	def Length(self) -> int: ...
	def LengthOfCString(self) -> int: ...
	def Remove(self, where: int, ahowmany: Optional[int] = 1) -> None: ...
	def RemoveAll(self, what: Standard_ExtCharacter) -> None: ...
	def Search(self, what: TCollection_ExtendedString) -> int: ...
	def SearchFromEnd(self, what: TCollection_ExtendedString) -> int: ...
	@overload
	def SetValue(self, where: int, what: Standard_ExtCharacter) -> None: ...
	@overload
	def SetValue(self, where: int, what: TCollection_ExtendedString) -> None: ...
	def Split(self, where: int) -> TCollection_ExtendedString: ...
	def StartsWith(self, theStartString: TCollection_ExtendedString) -> bool: ...
	def Swap(self, theOther: TCollection_ExtendedString) -> None: ...
	def ToExtString(self) -> Standard_ExtString: ...
	def ToUTF8CString(self, theCString: Standard_PCharacter) -> int: ...
	def Token(self, separators: Standard_ExtString, whichone: Optional[int] = 1) -> TCollection_ExtendedString: ...
	def Trunc(self, ahowmany: int) -> None: ...
	def Value(self, where: int) -> Standard_ExtCharacter: ...

class TCollection_HAsciiString(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, message: str) -> None: ...
	@overload
	def __init__(self, aChar: str) -> None: ...
	@overload
	def __init__(self, length: int, filler: str) -> None: ...
	@overload
	def __init__(self, value: int) -> None: ...
	@overload
	def __init__(self, value: float) -> None: ...
	@overload
	def __init__(self, aString: TCollection_AsciiString) -> None: ...
	@overload
	def __init__(self, aString: TCollection_HAsciiString) -> None: ...
	@overload
	def __init__(self, aString: TCollection_HExtendedString, replaceNonAscii: str) -> None: ...
	@overload
	def AssignCat(self, other: str) -> None: ...
	@overload
	def AssignCat(self, other: TCollection_HAsciiString) -> None: ...
	def Capitalize(self) -> None: ...
	@overload
	def Cat(self, other: str) -> TCollection_HAsciiString: ...
	@overload
	def Cat(self, other: TCollection_HAsciiString) -> TCollection_HAsciiString: ...
	def Center(self, Width: int, Filler: str) -> None: ...
	def ChangeAll(self, aChar: str, NewChar: str, CaseSensitive: Optional[bool] = True) -> None: ...
	def Clear(self) -> None: ...
	def FirstLocationInSet(self, Set: TCollection_HAsciiString, FromIndex: int, ToIndex: int) -> int: ...
	def FirstLocationNotInSet(self, Set: TCollection_HAsciiString, FromIndex: int, ToIndex: int) -> int: ...
	@overload
	def Insert(self, where: int, what: str) -> None: ...
	@overload
	def Insert(self, where: int, what: str) -> None: ...
	@overload
	def Insert(self, where: int, what: TCollection_HAsciiString) -> None: ...
	def InsertAfter(self, Index: int, other: TCollection_HAsciiString) -> None: ...
	def InsertBefore(self, Index: int, other: TCollection_HAsciiString) -> None: ...
	def IntegerValue(self) -> int: ...
	def IsAscii(self) -> bool: ...
	def IsDifferent(self, S: TCollection_HAsciiString) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def IsGreater(self, other: TCollection_HAsciiString) -> bool: ...
	def IsIntegerValue(self) -> bool: ...
	def IsLess(self, other: TCollection_HAsciiString) -> bool: ...
	def IsRealValue(self) -> bool: ...
	def IsSameState(self, other: TCollection_HAsciiString) -> bool: ...
	@overload
	def IsSameString(self, S: TCollection_HAsciiString) -> bool: ...
	@overload
	def IsSameString(self, S: TCollection_HAsciiString, CaseSensitive: bool) -> bool: ...
	def LeftAdjust(self) -> None: ...
	def LeftJustify(self, Width: int, Filler: str) -> None: ...
	def Length(self) -> int: ...
	@overload
	def Location(self, other: TCollection_HAsciiString, FromIndex: int, ToIndex: int) -> int: ...
	@overload
	def Location(self, N: int, C: str, FromIndex: int, ToIndex: int) -> int: ...
	def LowerCase(self) -> None: ...
	def Prepend(self, other: TCollection_HAsciiString) -> None: ...
	def RealValue(self) -> float: ...
	def Remove(self, where: int, ahowmany: Optional[int] = 1) -> None: ...
	@overload
	def RemoveAll(self, C: str, CaseSensitive: bool) -> None: ...
	@overload
	def RemoveAll(self, what: str) -> None: ...
	def RightAdjust(self) -> None: ...
	def RightJustify(self, Width: int, Filler: str) -> None: ...
	@overload
	def Search(self, what: str) -> int: ...
	@overload
	def Search(self, what: TCollection_HAsciiString) -> int: ...
	@overload
	def SearchFromEnd(self, what: str) -> int: ...
	@overload
	def SearchFromEnd(self, what: TCollection_HAsciiString) -> int: ...
	@overload
	def SetValue(self, where: int, what: str) -> None: ...
	@overload
	def SetValue(self, where: int, what: str) -> None: ...
	@overload
	def SetValue(self, where: int, what: TCollection_HAsciiString) -> None: ...
	def Split(self, where: int) -> TCollection_HAsciiString: ...
	def String(self) -> TCollection_AsciiString: ...
	def SubString(self, FromIndex: int, ToIndex: int) -> TCollection_HAsciiString: ...
	def ToCString(self) -> str: ...
	def Token(self, separators: Optional[str] = "\t", whichone: Optional[int] = 1) -> TCollection_HAsciiString: ...
	def Trunc(self, ahowmany: int) -> None: ...
	def UpperCase(self) -> None: ...
	def UsefullLength(self) -> int: ...
	def Value(self, where: int) -> str: ...

class TCollection_HExtendedString(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, message: str) -> None: ...
	@overload
	def __init__(self, message: Standard_ExtString) -> None: ...
	@overload
	def __init__(self, aChar: Standard_ExtCharacter) -> None: ...
	@overload
	def __init__(self, length: int, filler: Standard_ExtCharacter) -> None: ...
	@overload
	def __init__(self, aString: TCollection_ExtendedString) -> None: ...
	@overload
	def __init__(self, aString: TCollection_HAsciiString) -> None: ...
	@overload
	def __init__(self, aString: TCollection_HExtendedString) -> None: ...
	def AssignCat(self, other: TCollection_HExtendedString) -> None: ...
	def Cat(self, other: TCollection_HExtendedString) -> TCollection_HExtendedString: ...
	def ChangeAll(self, aChar: Standard_ExtCharacter, NewChar: Standard_ExtCharacter) -> None: ...
	def Clear(self) -> None: ...
	@overload
	def Insert(self, where: int, what: Standard_ExtCharacter) -> None: ...
	@overload
	def Insert(self, where: int, what: TCollection_HExtendedString) -> None: ...
	def IsAscii(self) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def IsGreater(self, other: TCollection_HExtendedString) -> bool: ...
	def IsLess(self, other: TCollection_HExtendedString) -> bool: ...
	def IsSameState(self, other: TCollection_HExtendedString) -> bool: ...
	def Length(self) -> int: ...
	def Remove(self, where: int, ahowmany: Optional[int] = 1) -> None: ...
	def RemoveAll(self, what: Standard_ExtCharacter) -> None: ...
	def Search(self, what: TCollection_HExtendedString) -> int: ...
	def SearchFromEnd(self, what: TCollection_HExtendedString) -> int: ...
	@overload
	def SetValue(self, where: int, what: Standard_ExtCharacter) -> None: ...
	@overload
	def SetValue(self, where: int, what: TCollection_HExtendedString) -> None: ...
	def Split(self, where: int) -> TCollection_HExtendedString: ...
	def String(self) -> TCollection_ExtendedString: ...
	def ToExtString(self) -> Standard_ExtString: ...
	def Token(self, separators: Standard_ExtString, whichone: Optional[int] = 1) -> TCollection_HExtendedString: ...
	def Trunc(self, ahowmany: int) -> None: ...
	def Value(self, where: int) -> Standard_ExtCharacter: ...

class TCollection_MapNode(Standard_Transient):
	def __init__(self, n: TCollection_MapNodePtr) -> None: ...
	def Next(self) -> TCollection_MapNodePtr: ...

class TCollection_SeqNode(Standard_Transient):
	def __init__(self, n: TCollection_SeqNodePtr, p: TCollection_SeqNodePtr) -> None: ...
	def Next(self) -> TCollection_SeqNodePtr: ...
	def Previous(self) -> TCollection_SeqNodePtr: ...

# harray1 classes
# harray2 classes
# hsequence classes

tcollection_NextPrimeForMap = tcollection.NextPrimeForMap
TCollection_AsciiString_HashCode = TCollection_AsciiString.HashCode
TCollection_AsciiString_IsEqual = TCollection_AsciiString.IsEqual
TCollection_AsciiString_IsEqual = TCollection_AsciiString.IsEqual
TCollection_AsciiString_IsSameString = TCollection_AsciiString.IsSameString
TCollection_ExtendedString_HashCode = TCollection_ExtendedString.HashCode
TCollection_ExtendedString_IsEqual = TCollection_ExtendedString.IsEqual



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColStd import *
from OCC.Core.TCollection import *

#the following typedef cannot be wrapped as is
Expr_MapOfNamedUnknown = NewType('Expr_MapOfNamedUnknown', Any)

class Expr_Array1OfGeneralExpression:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Expr_Array1OfNamedUnknown:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Expr_Array1OfSingleRelation:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Expr_SequenceOfGeneralExpression:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Expr_SequenceOfGeneralRelation:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class expr:
	@staticmethod
	def CopyShare(exp: Expr_GeneralExpression) -> Expr_GeneralExpression: ...
	@overload
	@staticmethod
	def NbOfFreeVariables(exp: Expr_GeneralExpression) -> int: ...
	@overload
	@staticmethod
	def NbOfFreeVariables(exp: Expr_GeneralRelation) -> int: ...
	@staticmethod
	def Sign(val: float) -> float: ...

class Expr_GeneralExpression(Standard_Transient):
	def Contains(self, exp: Expr_GeneralExpression) -> bool: ...
	def ContainsUnknowns(self) -> bool: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def EvaluateNumeric(self) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def IsShareable(self) -> bool: ...
	def NDerivative(self, X: Expr_NamedUnknown, N: int) -> Expr_GeneralExpression: ...
	def NbSubExpressions(self) -> int: ...
	def Replace(self, var: Expr_NamedUnknown, with_: Expr_GeneralExpression) -> None: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def Simplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...
	def SubExpression(self, I: int) -> Expr_GeneralExpression: ...

class Expr_GeneralFunction(Standard_Transient):
	def Copy(self) -> Expr_GeneralFunction: ...
	@overload
	def Derivative(self, var: Expr_NamedUnknown) -> Expr_GeneralFunction: ...
	@overload
	def Derivative(self, var: Expr_NamedUnknown, deg: int) -> Expr_GeneralFunction: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def GetStringName(self) -> TCollection_AsciiString: ...
	def IsIdentical(self, func: Expr_GeneralFunction) -> bool: ...
	def IsLinearOnVariable(self, index: int) -> bool: ...
	def NbOfVariables(self) -> int: ...
	def Variable(self, index: int) -> Expr_NamedUnknown: ...

class Expr_GeneralRelation(Standard_Transient):
	def Contains(self, exp: Expr_GeneralExpression) -> bool: ...
	def Copy(self) -> Expr_GeneralRelation: ...
	def IsLinear(self) -> bool: ...
	def IsSatisfied(self) -> bool: ...
	def NbOfSingleRelations(self) -> int: ...
	def NbOfSubRelations(self) -> int: ...
	def Replace(self, var: Expr_NamedUnknown, with_: Expr_GeneralExpression) -> None: ...
	def Simplified(self) -> Expr_GeneralRelation: ...
	def Simplify(self) -> None: ...
	def String(self) -> TCollection_AsciiString: ...
	def SubRelation(self, index: int) -> Expr_GeneralRelation: ...

class Expr_RUIterator:
	def __init__(self, rel: Expr_GeneralRelation) -> None: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Value(self) -> Expr_NamedUnknown: ...

class Expr_RelationIterator:
	def __init__(self, rel: Expr_GeneralRelation) -> None: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Value(self) -> Expr_SingleRelation: ...

class Expr_UnknownIterator:
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Value(self) -> Expr_NamedUnknown: ...

class Expr_BinaryExpression(Expr_GeneralExpression):
	def Contains(self, exp: Expr_GeneralExpression) -> bool: ...
	def ContainsUnknowns(self) -> bool: ...
	def FirstOperand(self) -> Expr_GeneralExpression: ...
	def NbSubExpressions(self) -> int: ...
	def Replace(self, var: Expr_NamedUnknown, with_: Expr_GeneralExpression) -> None: ...
	def SecondOperand(self) -> Expr_GeneralExpression: ...
	def SetFirstOperand(self, exp: Expr_GeneralExpression) -> None: ...
	def SetSecondOperand(self, exp: Expr_GeneralExpression) -> None: ...
	def Simplified(self) -> Expr_GeneralExpression: ...
	def SubExpression(self, I: int) -> Expr_GeneralExpression: ...

class Expr_FunctionDerivative(Expr_GeneralFunction):
	def __init__(self, func: Expr_GeneralFunction, withX: Expr_NamedUnknown, deg: int) -> None: ...
	def Copy(self) -> Expr_GeneralFunction: ...
	def Degree(self) -> int: ...
	def DerivVariable(self) -> Expr_NamedUnknown: ...
	@overload
	def Derivative(self, var: Expr_NamedUnknown) -> Expr_GeneralFunction: ...
	@overload
	def Derivative(self, var: Expr_NamedUnknown, deg: int) -> Expr_GeneralFunction: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, values: TColStd_Array1OfReal) -> float: ...
	def Expression(self) -> Expr_GeneralExpression: ...
	def Function(self) -> Expr_GeneralFunction: ...
	def GetStringName(self) -> TCollection_AsciiString: ...
	def IsIdentical(self, func: Expr_GeneralFunction) -> bool: ...
	def IsLinearOnVariable(self, index: int) -> bool: ...
	def NbOfVariables(self) -> int: ...
	def UpdateExpression(self) -> None: ...
	def Variable(self, index: int) -> Expr_NamedUnknown: ...

class Expr_NamedExpression(Expr_GeneralExpression):
	def GetName(self) -> TCollection_AsciiString: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsShareable(self) -> bool: ...
	def SetName(self, name: TCollection_AsciiString) -> None: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_NamedFunction(Expr_GeneralFunction):
	def __init__(self, name: TCollection_AsciiString, exp: Expr_GeneralExpression, vars: Expr_Array1OfNamedUnknown) -> None: ...
	def Copy(self) -> Expr_GeneralFunction: ...
	@overload
	def Derivative(self, var: Expr_NamedUnknown) -> Expr_GeneralFunction: ...
	@overload
	def Derivative(self, var: Expr_NamedUnknown, deg: int) -> Expr_GeneralFunction: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, values: TColStd_Array1OfReal) -> float: ...
	def Expression(self) -> Expr_GeneralExpression: ...
	def GetName(self) -> TCollection_AsciiString: ...
	def GetStringName(self) -> TCollection_AsciiString: ...
	def IsIdentical(self, func: Expr_GeneralFunction) -> bool: ...
	def IsLinearOnVariable(self, index: int) -> bool: ...
	def NbOfVariables(self) -> int: ...
	def SetExpression(self, exp: Expr_GeneralExpression) -> None: ...
	def SetName(self, newname: TCollection_AsciiString) -> None: ...
	def Variable(self, index: int) -> Expr_NamedUnknown: ...

class Expr_NumericValue(Expr_GeneralExpression):
	def __init__(self, val: float) -> None: ...
	def Contains(self, exp: Expr_GeneralExpression) -> bool: ...
	def ContainsUnknowns(self) -> bool: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def GetValue(self) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def NDerivative(self, X: Expr_NamedUnknown, N: int) -> Expr_GeneralExpression: ...
	def NbSubExpressions(self) -> int: ...
	def Replace(self, var: Expr_NamedUnknown, with_: Expr_GeneralExpression) -> None: ...
	def SetValue(self, val: float) -> None: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def Simplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...
	def SubExpression(self, I: int) -> Expr_GeneralExpression: ...

class Expr_PolyExpression(Expr_GeneralExpression):
	def Contains(self, exp: Expr_GeneralExpression) -> bool: ...
	def ContainsUnknowns(self) -> bool: ...
	def NbOperands(self) -> int: ...
	def NbSubExpressions(self) -> int: ...
	def Operand(self, index: int) -> Expr_GeneralExpression: ...
	def Replace(self, var: Expr_NamedUnknown, with_: Expr_GeneralExpression) -> None: ...
	def SetOperand(self, exp: Expr_GeneralExpression, index: int) -> None: ...
	def Simplified(self) -> Expr_GeneralExpression: ...
	def SubExpression(self, I: int) -> Expr_GeneralExpression: ...

class Expr_SingleRelation(Expr_GeneralRelation):
	def Contains(self, exp: Expr_GeneralExpression) -> bool: ...
	def FirstMember(self) -> Expr_GeneralExpression: ...
	def IsLinear(self) -> bool: ...
	def NbOfSingleRelations(self) -> int: ...
	def NbOfSubRelations(self) -> int: ...
	def Replace(self, var: Expr_NamedUnknown, with_: Expr_GeneralExpression) -> None: ...
	def SecondMember(self) -> Expr_GeneralExpression: ...
	def SetFirstMember(self, exp: Expr_GeneralExpression) -> None: ...
	def SetSecondMember(self, exp: Expr_GeneralExpression) -> None: ...
	def SubRelation(self, index: int) -> Expr_GeneralRelation: ...

class Expr_SystemRelation(Expr_GeneralRelation):
	def __init__(self, relation: Expr_GeneralRelation) -> None: ...
	def Add(self, relation: Expr_GeneralRelation) -> None: ...
	def Contains(self, exp: Expr_GeneralExpression) -> bool: ...
	def Copy(self) -> Expr_GeneralRelation: ...
	def IsLinear(self) -> bool: ...
	def IsSatisfied(self) -> bool: ...
	def NbOfSingleRelations(self) -> int: ...
	def NbOfSubRelations(self) -> int: ...
	def Remove(self, relation: Expr_GeneralRelation) -> None: ...
	def Replace(self, var: Expr_NamedUnknown, with_: Expr_GeneralExpression) -> None: ...
	def Simplified(self) -> Expr_GeneralRelation: ...
	def Simplify(self) -> None: ...
	def String(self) -> TCollection_AsciiString: ...
	def SubRelation(self, index: int) -> Expr_GeneralRelation: ...

class Expr_UnaryExpression(Expr_GeneralExpression):
	def Contains(self, exp: Expr_GeneralExpression) -> bool: ...
	def ContainsUnknowns(self) -> bool: ...
	def NbSubExpressions(self) -> int: ...
	def Operand(self) -> Expr_GeneralExpression: ...
	def Replace(self, var: Expr_NamedUnknown, with_: Expr_GeneralExpression) -> None: ...
	def SetOperand(self, exp: Expr_GeneralExpression) -> None: ...
	def Simplified(self) -> Expr_GeneralExpression: ...
	def SubExpression(self, I: int) -> Expr_GeneralExpression: ...

class Expr_Absolute(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_ArcCosine(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_ArcSine(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_ArcTangent(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_ArgCosh(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_ArgSinh(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_ArgTanh(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_BinaryFunction(Expr_BinaryExpression):
	def __init__(self, func: Expr_GeneralFunction, exp1: Expr_GeneralExpression, exp2: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def Function(self) -> Expr_GeneralFunction: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_Cosh(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_Cosine(Expr_UnaryExpression):
	def __init__(self, Exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_Difference(Expr_BinaryExpression):
	def __init__(self, exp1: Expr_GeneralExpression, exp2: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def NDerivative(self, X: Expr_NamedUnknown, N: int) -> Expr_GeneralExpression: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_Different(Expr_SingleRelation):
	def __init__(self, exp1: Expr_GeneralExpression, exp2: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralRelation: ...
	def IsSatisfied(self) -> bool: ...
	def Simplified(self) -> Expr_GeneralRelation: ...
	def Simplify(self) -> None: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_Division(Expr_BinaryExpression):
	def __init__(self, exp1: Expr_GeneralExpression, exp2: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_Equal(Expr_SingleRelation):
	def __init__(self, exp1: Expr_GeneralExpression, exp2: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralRelation: ...
	def IsSatisfied(self) -> bool: ...
	def Simplified(self) -> Expr_GeneralRelation: ...
	def Simplify(self) -> None: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_Exponential(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_Exponentiate(Expr_BinaryExpression):
	def __init__(self, exp1: Expr_GeneralExpression, exp2: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_GreaterThan(Expr_SingleRelation):
	def __init__(self, exp1: Expr_GeneralExpression, exp2: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralRelation: ...
	def IsSatisfied(self) -> bool: ...
	def Simplified(self) -> Expr_GeneralRelation: ...
	def Simplify(self) -> None: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_GreaterThanOrEqual(Expr_SingleRelation):
	def __init__(self, exp1: Expr_GeneralExpression, exp2: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralRelation: ...
	def IsSatisfied(self) -> bool: ...
	def Simplified(self) -> Expr_GeneralRelation: ...
	def Simplify(self) -> None: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_LessThan(Expr_SingleRelation):
	def __init__(self, exp1: Expr_GeneralExpression, exp2: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralRelation: ...
	def IsSatisfied(self) -> bool: ...
	def Simplified(self) -> Expr_GeneralRelation: ...
	def Simplify(self) -> None: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_LessThanOrEqual(Expr_SingleRelation):
	def __init__(self, exp1: Expr_GeneralExpression, exp2: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralRelation: ...
	def IsSatisfied(self) -> bool: ...
	def Simplified(self) -> Expr_GeneralRelation: ...
	def Simplify(self) -> None: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_LogOf10(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_LogOfe(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_NamedConstant(Expr_NamedExpression):
	def __init__(self, name: TCollection_AsciiString, value: float) -> None: ...
	def Contains(self, exp: Expr_GeneralExpression) -> bool: ...
	def ContainsUnknowns(self) -> bool: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def GetValue(self) -> float: ...
	def IsLinear(self) -> bool: ...
	def NDerivative(self, X: Expr_NamedUnknown, N: int) -> Expr_GeneralExpression: ...
	def NbSubExpressions(self) -> int: ...
	def Replace(self, var: Expr_NamedUnknown, with_: Expr_GeneralExpression) -> None: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def Simplified(self) -> Expr_GeneralExpression: ...
	def SubExpression(self, I: int) -> Expr_GeneralExpression: ...

class Expr_NamedUnknown(Expr_NamedExpression):
	def __init__(self, name: TCollection_AsciiString) -> None: ...
	def Assign(self, exp: Expr_GeneralExpression) -> None: ...
	def AssignedExpression(self) -> Expr_GeneralExpression: ...
	def Contains(self, exp: Expr_GeneralExpression) -> bool: ...
	def ContainsUnknowns(self) -> bool: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Deassign(self) -> None: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsAssigned(self) -> bool: ...
	def IsLinear(self) -> bool: ...
	def NbSubExpressions(self) -> int: ...
	def Replace(self, var: Expr_NamedUnknown, with_: Expr_GeneralExpression) -> None: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def Simplified(self) -> Expr_GeneralExpression: ...
	def SubExpression(self, I: int) -> Expr_GeneralExpression: ...

class Expr_PolyFunction(Expr_PolyExpression):
	def __init__(self, func: Expr_GeneralFunction, exps: Expr_Array1OfGeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def Function(self) -> Expr_GeneralFunction: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_Product(Expr_PolyExpression):
	@overload
	def __init__(self, exps: Expr_SequenceOfGeneralExpression) -> None: ...
	@overload
	def __init__(self, exp1: Expr_GeneralExpression, exp2: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_Sine(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_Sinh(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_Square(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_SquareRoot(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_Sum(Expr_PolyExpression):
	@overload
	def __init__(self, exps: Expr_SequenceOfGeneralExpression) -> None: ...
	@overload
	def __init__(self, exp1: Expr_GeneralExpression, exp2: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def NDerivative(self, X: Expr_NamedUnknown, N: int) -> Expr_GeneralExpression: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_Tangent(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_Tanh(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_UnaryFunction(Expr_UnaryExpression):
	def __init__(self, func: Expr_GeneralFunction, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def Function(self) -> Expr_GeneralFunction: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

class Expr_UnaryMinus(Expr_UnaryExpression):
	def __init__(self, exp: Expr_GeneralExpression) -> None: ...
	def Copy(self) -> Expr_GeneralExpression: ...
	def Derivative(self, X: Expr_NamedUnknown) -> Expr_GeneralExpression: ...
	def Evaluate(self, vars: Expr_Array1OfNamedUnknown, vals: TColStd_Array1OfReal) -> float: ...
	def IsIdentical(self, Other: Expr_GeneralExpression) -> bool: ...
	def IsLinear(self) -> bool: ...
	def NDerivative(self, X: Expr_NamedUnknown, N: int) -> Expr_GeneralExpression: ...
	def ShallowSimplified(self) -> Expr_GeneralExpression: ...
	def String(self) -> TCollection_AsciiString: ...

#classnotwrapped
class Expr_Sign: ...

# harray1 classes
# harray2 classes
# hsequence classes

expr_CopyShare = expr.CopyShare
expr_NbOfFreeVariables = expr.NbOfFreeVariables
expr_NbOfFreeVariables = expr.NbOfFreeVariables
expr_Sign = expr.Sign



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Adaptor3d import *
from OCC.Core.Geom import *
from OCC.Core.gp import *
from OCC.Core.GeomAbs import *
from OCC.Core.TColStd import *


class geomadaptor:
	@staticmethod
	def MakeCurve(C: Adaptor3d_Curve) -> Geom_Curve: ...
	@staticmethod
	def MakeSurface(theS: Adaptor3d_Surface, theTrimFlag: Optional[bool] = True) -> Geom_Surface: ...

class GeomAdaptor_Curve(Adaptor3d_Curve):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Geom_Curve) -> None: ...
	@overload
	def __init__(self, C: Geom_Curve, UFirst: float, ULast: float) -> None: ...
	def BSpline(self) -> Geom_BSplineCurve: ...
	def Bezier(self) -> Geom_BezierCurve: ...
	def Circle(self) -> gp_Circ: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Curve(self) -> Geom_Curve: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def Degree(self) -> int: ...
	def Ellipse(self) -> gp_Elips: ...
	def FirstParameter(self) -> float: ...
	def GetType(self) -> GeomAbs_CurveType: ...
	def Hyperbola(self) -> gp_Hypr: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def IsRational(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def Line(self) -> gp_Lin: ...
	@overload
	def Load(self, C: Geom_Curve) -> None: ...
	@overload
	def Load(self, C: Geom_Curve, UFirst: float, ULast: float) -> None: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbKnots(self) -> int: ...
	def NbPoles(self) -> int: ...
	def OffsetCurve(self) -> Geom_OffsetCurve: ...
	def Parabola(self) -> gp_Parab: ...
	def Period(self) -> float: ...
	def Reset(self) -> None: ...
	def Resolution(self, R3d: float) -> float: ...
	def Trim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HCurve: ...
	def Value(self, U: float) -> gp_Pnt: ...

class GeomAdaptor_GHCurve(Adaptor3d_HCurve):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: GeomAdaptor_Curve) -> None: ...
	def ChangeCurve(self) -> GeomAdaptor_Curve: ...
	def Curve(self) -> Adaptor3d_Curve: ...
	def GetCurve(self) -> Adaptor3d_Curve: ...
	def Set(self, C: GeomAdaptor_Curve) -> None: ...

class GeomAdaptor_GHSurface(Adaptor3d_HSurface):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: GeomAdaptor_Surface) -> None: ...
	def ChangeSurface(self) -> GeomAdaptor_Surface: ...
	def Set(self, S: GeomAdaptor_Surface) -> None: ...
	def Surface(self) -> Adaptor3d_Surface: ...

class GeomAdaptor_HSurfaceOfLinearExtrusion(Adaptor3d_HSurface):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: GeomAdaptor_SurfaceOfLinearExtrusion) -> None: ...
	def ChangeSurface(self) -> GeomAdaptor_SurfaceOfLinearExtrusion: ...
	def Set(self, S: GeomAdaptor_SurfaceOfLinearExtrusion) -> None: ...
	def Surface(self) -> Adaptor3d_Surface: ...

class GeomAdaptor_HSurfaceOfRevolution(Adaptor3d_HSurface):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: GeomAdaptor_SurfaceOfRevolution) -> None: ...
	def ChangeSurface(self) -> GeomAdaptor_SurfaceOfRevolution: ...
	def Set(self, S: GeomAdaptor_SurfaceOfRevolution) -> None: ...
	def Surface(self) -> Adaptor3d_Surface: ...

class GeomAdaptor_Surface(Adaptor3d_Surface):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: Geom_Surface) -> None: ...
	@overload
	def __init__(self, S: Geom_Surface, UFirst: float, ULast: float, VFirst: float, VLast: float, TolU: Optional[float] = 0.0, TolV: Optional[float] = 0.0) -> None: ...
	def AxeOfRevolution(self) -> gp_Ax1: ...
	def BSpline(self) -> Geom_BSplineSurface: ...
	def BasisCurve(self) -> Adaptor3d_HCurve: ...
	def BasisSurface(self) -> Adaptor3d_HSurface: ...
	def Bezier(self) -> Geom_BezierSurface: ...
	def Cone(self) -> gp_Cone: ...
	def Cylinder(self) -> gp_Cylinder: ...
	def D0(self, U: float, V: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	def D2(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	def D3(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	def DN(self, U: float, V: float, Nu: int, Nv: int) -> gp_Vec: ...
	def Direction(self) -> gp_Dir: ...
	def FirstUParameter(self) -> float: ...
	def FirstVParameter(self) -> float: ...
	def GetType(self) -> GeomAbs_SurfaceType: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsURational(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def IsVRational(self) -> bool: ...
	def LastUParameter(self) -> float: ...
	def LastVParameter(self) -> float: ...
	@overload
	def Load(self, S: Geom_Surface) -> None: ...
	@overload
	def Load(self, S: Geom_Surface, UFirst: float, ULast: float, VFirst: float, VLast: float, TolU: Optional[float] = 0.0, TolV: Optional[float] = 0.0) -> None: ...
	def NbUIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbUKnots(self) -> int: ...
	def NbUPoles(self) -> int: ...
	def NbVIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbVKnots(self) -> int: ...
	def NbVPoles(self) -> int: ...
	def OffsetValue(self) -> float: ...
	def Plane(self) -> gp_Pln: ...
	def Sphere(self) -> gp_Sphere: ...
	def Surface(self) -> Geom_Surface: ...
	def Torus(self) -> gp_Torus: ...
	def UContinuity(self) -> GeomAbs_Shape: ...
	def UDegree(self) -> int: ...
	def UIntervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def UPeriod(self) -> float: ...
	def UResolution(self, R3d: float) -> float: ...
	def UTrim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HSurface: ...
	def VContinuity(self) -> GeomAbs_Shape: ...
	def VDegree(self) -> int: ...
	def VIntervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def VPeriod(self) -> float: ...
	def VResolution(self, R3d: float) -> float: ...
	def VTrim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HSurface: ...
	def Value(self, U: float, V: float) -> gp_Pnt: ...

class GeomAdaptor_HCurve(GeomAdaptor_GHCurve):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, AS: GeomAdaptor_Curve) -> None: ...
	@overload
	def __init__(self, S: Geom_Curve) -> None: ...
	@overload
	def __init__(self, S: Geom_Curve, UFirst: float, ULast: float) -> None: ...

class GeomAdaptor_HSurface(GeomAdaptor_GHSurface):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, AS: GeomAdaptor_Surface) -> None: ...
	@overload
	def __init__(self, S: Geom_Surface) -> None: ...
	@overload
	def __init__(self, S: Geom_Surface, UFirst: float, ULast: float, VFirst: float, VLast: float, TolU: Optional[float] = 0.0, TolV: Optional[float] = 0.0) -> None: ...

class GeomAdaptor_SurfaceOfLinearExtrusion(GeomAdaptor_Surface):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_HCurve) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_HCurve, V: gp_Dir) -> None: ...
	def AxeOfRevolution(self) -> gp_Ax1: ...
	def BSpline(self) -> Geom_BSplineSurface: ...
	def BasisCurve(self) -> Adaptor3d_HCurve: ...
	def Bezier(self) -> Geom_BezierSurface: ...
	def Cone(self) -> gp_Cone: ...
	def Cylinder(self) -> gp_Cylinder: ...
	def Direction(self) -> gp_Dir: ...
	def FirstUParameter(self) -> float: ...
	def FirstVParameter(self) -> float: ...
	def GetType(self) -> GeomAbs_SurfaceType: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsURational(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def IsVRational(self) -> bool: ...
	def LastUParameter(self) -> float: ...
	def LastVParameter(self) -> float: ...
	@overload
	def Load(self, C: Adaptor3d_HCurve) -> None: ...
	@overload
	def Load(self, V: gp_Dir) -> None: ...
	def NbUIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbUPoles(self) -> int: ...
	def NbVIntervals(self, S: GeomAbs_Shape) -> int: ...
	def Plane(self) -> gp_Pln: ...
	def Sphere(self) -> gp_Sphere: ...
	def Torus(self) -> gp_Torus: ...
	def UContinuity(self) -> GeomAbs_Shape: ...
	def UDegree(self) -> int: ...
	def UIntervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def UPeriod(self) -> float: ...
	def UResolution(self, R3d: float) -> float: ...
	def UTrim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HSurface: ...
	def VContinuity(self) -> GeomAbs_Shape: ...
	def VIntervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def VPeriod(self) -> float: ...
	def VResolution(self, R3d: float) -> float: ...
	def VTrim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HSurface: ...

class GeomAdaptor_SurfaceOfRevolution(GeomAdaptor_Surface):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_HCurve) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_HCurve, V: gp_Ax1) -> None: ...
	def AxeOfRevolution(self) -> gp_Ax1: ...
	def Axis(self) -> gp_Ax3: ...
	def BSpline(self) -> Geom_BSplineSurface: ...
	def BasisCurve(self) -> Adaptor3d_HCurve: ...
	def Bezier(self) -> Geom_BezierSurface: ...
	def Cone(self) -> gp_Cone: ...
	def Cylinder(self) -> gp_Cylinder: ...
	def FirstUParameter(self) -> float: ...
	def FirstVParameter(self) -> float: ...
	def GetType(self) -> GeomAbs_SurfaceType: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsURational(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def IsVRational(self) -> bool: ...
	def LastUParameter(self) -> float: ...
	def LastVParameter(self) -> float: ...
	@overload
	def Load(self, C: Adaptor3d_HCurve) -> None: ...
	@overload
	def Load(self, V: gp_Ax1) -> None: ...
	def NbUIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbVIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbVKnots(self) -> int: ...
	def NbVPoles(self) -> int: ...
	def Plane(self) -> gp_Pln: ...
	def Sphere(self) -> gp_Sphere: ...
	def Torus(self) -> gp_Torus: ...
	def UContinuity(self) -> GeomAbs_Shape: ...
	def UIntervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def UPeriod(self) -> float: ...
	def UResolution(self, R3d: float) -> float: ...
	def UTrim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HSurface: ...
	def VContinuity(self) -> GeomAbs_Shape: ...
	def VDegree(self) -> int: ...
	def VIntervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def VPeriod(self) -> float: ...
	def VResolution(self, R3d: float) -> float: ...
	def VTrim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HSurface: ...

# harray1 classes
# harray2 classes
# hsequence classes

geomadaptor_MakeCurve = geomadaptor.MakeCurve
geomadaptor_MakeSurface = geomadaptor.MakeSurface



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.math import *
from OCC.Core.Adaptor3d import *
from OCC.Core.Geom import *
from OCC.Core.GeomAbs import *
from OCC.Core.TColStd import *
from OCC.Core.Intf import *
from OCC.Core.Bnd import *
from OCC.Core.IntSurf import *


class IntCurveSurface_SequenceOfPnt:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> IntCurveSurface_IntersectionPoint: ...
    def Last(self) -> IntCurveSurface_IntersectionPoint: ...
    def Length(self) -> int: ...
    def Append(self, theItem: IntCurveSurface_IntersectionPoint) -> IntCurveSurface_IntersectionPoint: ...
    def Prepend(self, theItem: IntCurveSurface_IntersectionPoint) -> IntCurveSurface_IntersectionPoint: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> IntCurveSurface_IntersectionPoint: ...
    def SetValue(self, theIndex: int, theValue: IntCurveSurface_IntersectionPoint) -> None: ...

class IntCurveSurface_SequenceOfSeg:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> IntCurveSurface_IntersectionSegment: ...
    def Last(self) -> IntCurveSurface_IntersectionSegment: ...
    def Length(self) -> int: ...
    def Append(self, theItem: IntCurveSurface_IntersectionSegment) -> IntCurveSurface_IntersectionSegment: ...
    def Prepend(self, theItem: IntCurveSurface_IntersectionSegment) -> IntCurveSurface_IntersectionSegment: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> IntCurveSurface_IntersectionSegment: ...
    def SetValue(self, theIndex: int, theValue: IntCurveSurface_IntersectionSegment) -> None: ...

class IntCurveSurface_TransitionOnCurve(IntEnum):
	IntCurveSurface_Tangent: int = ...
	IntCurveSurface_In: int = ...
	IntCurveSurface_Out: int = ...
IntCurveSurface_Tangent = IntCurveSurface_TransitionOnCurve.IntCurveSurface_Tangent
IntCurveSurface_In = IntCurveSurface_TransitionOnCurve.IntCurveSurface_In
IntCurveSurface_Out = IntCurveSurface_TransitionOnCurve.IntCurveSurface_Out

class IntCurveSurface_Intersection:
	def Dump(self) -> None: ...
	def IsDone(self) -> bool: ...
	def IsParallel(self) -> bool: ...
	def NbPoints(self) -> int: ...
	def NbSegments(self) -> int: ...
	def Point(self, Index: int) -> IntCurveSurface_IntersectionPoint: ...
	def Segment(self, Index: int) -> IntCurveSurface_IntersectionSegment: ...

class IntCurveSurface_IntersectionPoint:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, USurf: float, VSurf: float, UCurv: float, TrCurv: IntCurveSurface_TransitionOnCurve) -> None: ...
	def Dump(self) -> None: ...
	def Pnt(self) -> gp_Pnt: ...
	def SetValues(self, P: gp_Pnt, USurf: float, VSurf: float, UCurv: float, TrCurv: IntCurveSurface_TransitionOnCurve) -> None: ...
	def Transition(self) -> IntCurveSurface_TransitionOnCurve: ...
	def U(self) -> float: ...
	def V(self) -> float: ...
	def Values(self, P: gp_Pnt, TrCurv: IntCurveSurface_TransitionOnCurve) -> Tuple[float, float, float]: ...
	def W(self) -> float: ...

class IntCurveSurface_IntersectionSegment:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P1: IntCurveSurface_IntersectionPoint, P2: IntCurveSurface_IntersectionPoint) -> None: ...
	def Dump(self) -> None: ...
	@overload
	def FirstPoint(self, P1: IntCurveSurface_IntersectionPoint) -> None: ...
	@overload
	def FirstPoint(self) -> IntCurveSurface_IntersectionPoint: ...
	@overload
	def SecondPoint(self, P2: IntCurveSurface_IntersectionPoint) -> None: ...
	@overload
	def SecondPoint(self) -> IntCurveSurface_IntersectionPoint: ...
	def SetValues(self, P1: IntCurveSurface_IntersectionPoint, P2: IntCurveSurface_IntersectionPoint) -> None: ...
	def Values(self, P1: IntCurveSurface_IntersectionPoint, P2: IntCurveSurface_IntersectionPoint) -> None: ...

class IntCurveSurface_TheCSFunctionOfHInter(math_FunctionSetWithDerivatives):
	def __init__(self, S: Adaptor3d_HSurface, C: Adaptor3d_HCurve) -> None: ...
	def AuxillarCurve(self) -> Adaptor3d_HCurve: ...
	def AuxillarSurface(self) -> Adaptor3d_HSurface: ...
	def Derivatives(self, X: math_Vector, D: math_Matrix) -> bool: ...
	def NbEquations(self) -> int: ...
	def NbVariables(self) -> int: ...
	def Point(self) -> gp_Pnt: ...
	def Root(self) -> float: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...
	def Values(self, X: math_Vector, F: math_Vector, D: math_Matrix) -> bool: ...

class IntCurveSurface_TheExactHInter:
	@overload
	def __init__(self, U: float, V: float, W: float, F: IntCurveSurface_TheCSFunctionOfHInter, TolTangency: float, MarginCoef: Optional[float] = 0.0) -> None: ...
	@overload
	def __init__(self, F: IntCurveSurface_TheCSFunctionOfHInter, TolTangency: float) -> None: ...
	def Function(self) -> IntCurveSurface_TheCSFunctionOfHInter: ...
	def IsDone(self) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def ParameterOnCurve(self) -> float: ...
	def ParameterOnSurface(self) -> Tuple[float, float]: ...
	def Perform(self, U: float, V: float, W: float, Rsnld: math_FunctionSetRoot, u0: float, v0: float, u1: float, v1: float, w0: float, w1: float) -> None: ...
	def Point(self) -> gp_Pnt: ...

class IntCurveSurface_TheHCurveTool:
	@staticmethod
	def BSpline(C: Adaptor3d_HCurve) -> Geom_BSplineCurve: ...
	@staticmethod
	def Bezier(C: Adaptor3d_HCurve) -> Geom_BezierCurve: ...
	@staticmethod
	def Circle(C: Adaptor3d_HCurve) -> gp_Circ: ...
	@staticmethod
	def Continuity(C: Adaptor3d_HCurve) -> GeomAbs_Shape: ...
	@staticmethod
	def D0(C: Adaptor3d_HCurve, U: float, P: gp_Pnt) -> None: ...
	@staticmethod
	def D1(C: Adaptor3d_HCurve, U: float, P: gp_Pnt, V: gp_Vec) -> None: ...
	@staticmethod
	def D2(C: Adaptor3d_HCurve, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	@staticmethod
	def D3(C: Adaptor3d_HCurve, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	@staticmethod
	def DN(C: Adaptor3d_HCurve, U: float, N: int) -> gp_Vec: ...
	@staticmethod
	def Ellipse(C: Adaptor3d_HCurve) -> gp_Elips: ...
	@staticmethod
	def FirstParameter(C: Adaptor3d_HCurve) -> float: ...
	@staticmethod
	def GetType(C: Adaptor3d_HCurve) -> GeomAbs_CurveType: ...
	@staticmethod
	def Hyperbola(C: Adaptor3d_HCurve) -> gp_Hypr: ...
	@staticmethod
	def Intervals(C: Adaptor3d_HCurve, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	@staticmethod
	def IsClosed(C: Adaptor3d_HCurve) -> bool: ...
	@staticmethod
	def IsPeriodic(C: Adaptor3d_HCurve) -> bool: ...
	@staticmethod
	def LastParameter(C: Adaptor3d_HCurve) -> float: ...
	@staticmethod
	def Line(C: Adaptor3d_HCurve) -> gp_Lin: ...
	@staticmethod
	def NbIntervals(C: Adaptor3d_HCurve, S: GeomAbs_Shape) -> int: ...
	@staticmethod
	def NbSamples(C: Adaptor3d_HCurve, U0: float, U1: float) -> int: ...
	@staticmethod
	def Parabola(C: Adaptor3d_HCurve) -> gp_Parab: ...
	@staticmethod
	def Period(C: Adaptor3d_HCurve) -> float: ...
	@staticmethod
	def Resolution(C: Adaptor3d_HCurve, R3d: float) -> float: ...
	@staticmethod
	def SamplePars(C: Adaptor3d_HCurve, U0: float, U1: float, Defl: float, NbMin: int, Pars: TColStd_HArray1OfReal) -> None: ...
	@staticmethod
	def Value(C: Adaptor3d_HCurve, U: float) -> gp_Pnt: ...

class IntCurveSurface_TheInterferenceOfHInter(Intf_Interference):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, thePolyg: IntCurveSurface_ThePolygonOfHInter, thePolyh: IntCurveSurface_ThePolyhedronOfHInter) -> None: ...
	@overload
	def __init__(self, theLin: gp_Lin, thePolyh: IntCurveSurface_ThePolyhedronOfHInter) -> None: ...
	@overload
	def __init__(self, theLins: Intf_Array1OfLin, thePolyh: IntCurveSurface_ThePolyhedronOfHInter) -> None: ...
	@overload
	def __init__(self, thePolyg: IntCurveSurface_ThePolygonOfHInter, thePolyh: IntCurveSurface_ThePolyhedronOfHInter, theBoundSB: Bnd_BoundSortBox) -> None: ...
	@overload
	def __init__(self, theLin: gp_Lin, thePolyh: IntCurveSurface_ThePolyhedronOfHInter, theBoundSB: Bnd_BoundSortBox) -> None: ...
	@overload
	def __init__(self, theLins: Intf_Array1OfLin, thePolyh: IntCurveSurface_ThePolyhedronOfHInter, theBoundSB: Bnd_BoundSortBox) -> None: ...
	@overload
	def Interference(self, thePolyg: IntCurveSurface_ThePolygonOfHInter, thePolyh: IntCurveSurface_ThePolyhedronOfHInter, theBoundSB: Bnd_BoundSortBox) -> None: ...
	@overload
	def Interference(self, thePolyg: IntCurveSurface_ThePolygonOfHInter, thePolyh: IntCurveSurface_ThePolyhedronOfHInter) -> None: ...
	@overload
	def Perform(self, thePolyg: IntCurveSurface_ThePolygonOfHInter, thePolyh: IntCurveSurface_ThePolyhedronOfHInter) -> None: ...
	@overload
	def Perform(self, theLin: gp_Lin, thePolyh: IntCurveSurface_ThePolyhedronOfHInter) -> None: ...
	@overload
	def Perform(self, theLins: Intf_Array1OfLin, thePolyh: IntCurveSurface_ThePolyhedronOfHInter) -> None: ...
	@overload
	def Perform(self, thePolyg: IntCurveSurface_ThePolygonOfHInter, thePolyh: IntCurveSurface_ThePolyhedronOfHInter, theBoundSB: Bnd_BoundSortBox) -> None: ...
	@overload
	def Perform(self, theLin: gp_Lin, thePolyh: IntCurveSurface_ThePolyhedronOfHInter, theBoundSB: Bnd_BoundSortBox) -> None: ...
	@overload
	def Perform(self, theLins: Intf_Array1OfLin, thePolyh: IntCurveSurface_ThePolyhedronOfHInter, theBoundSB: Bnd_BoundSortBox) -> None: ...

class IntCurveSurface_ThePolygonOfHInter:
	@overload
	def __init__(self, Curve: Adaptor3d_HCurve, NbPnt: int) -> None: ...
	@overload
	def __init__(self, Curve: Adaptor3d_HCurve, U1: float, U2: float, NbPnt: int) -> None: ...
	@overload
	def __init__(self, Curve: Adaptor3d_HCurve, Upars: TColStd_Array1OfReal) -> None: ...
	def ApproxParamOnCurve(self, Index: int, ParamOnLine: float) -> float: ...
	def BeginOfSeg(self, Index: int) -> gp_Pnt: ...
	def Bounding(self) -> Bnd_Box: ...
	@overload
	def Closed(self, clos: bool) -> None: ...
	@overload
	def Closed(self) -> bool: ...
	def DeflectionOverEstimation(self) -> float: ...
	def Dump(self) -> None: ...
	def EndOfSeg(self, Index: int) -> gp_Pnt: ...
	def InfParameter(self) -> float: ...
	def NbSegments(self) -> int: ...
	def SetDeflectionOverEstimation(self, x: float) -> None: ...
	def SupParameter(self) -> float: ...

class IntCurveSurface_ThePolygonToolOfHInter:
	@staticmethod
	def BeginOfSeg(thePolygon: IntCurveSurface_ThePolygonOfHInter, Index: int) -> gp_Pnt: ...
	@staticmethod
	def Bounding(thePolygon: IntCurveSurface_ThePolygonOfHInter) -> Bnd_Box: ...
	@staticmethod
	def Closed(thePolygon: IntCurveSurface_ThePolygonOfHInter) -> bool: ...
	@staticmethod
	def DeflectionOverEstimation(thePolygon: IntCurveSurface_ThePolygonOfHInter) -> float: ...
	@staticmethod
	def Dump(thePolygon: IntCurveSurface_ThePolygonOfHInter) -> None: ...
	@staticmethod
	def EndOfSeg(thePolygon: IntCurveSurface_ThePolygonOfHInter, Index: int) -> gp_Pnt: ...
	@staticmethod
	def NbSegments(thePolygon: IntCurveSurface_ThePolygonOfHInter) -> int: ...

class IntCurveSurface_ThePolyhedronToolOfHInter:
	@staticmethod
	def Bounding(thePolyh: IntCurveSurface_ThePolyhedronOfHInter) -> Bnd_Box: ...
	@staticmethod
	def ComponentsBounding(thePolyh: IntCurveSurface_ThePolyhedronOfHInter) -> Bnd_HArray1OfBox: ...
	@staticmethod
	def DeflectionOverEstimation(thePolyh: IntCurveSurface_ThePolyhedronOfHInter) -> float: ...
	@staticmethod
	def Dump(thePolyh: IntCurveSurface_ThePolyhedronOfHInter) -> None: ...
	@staticmethod
	def GetBorderDeflection(thePolyh: IntCurveSurface_ThePolyhedronOfHInter) -> float: ...
	@staticmethod
	def IsOnBound(thePolyh: IntCurveSurface_ThePolyhedronOfHInter, Index1: int, Index2: int) -> bool: ...
	@staticmethod
	def NbTriangles(thePolyh: IntCurveSurface_ThePolyhedronOfHInter) -> int: ...
	@staticmethod
	def Point(thePolyh: IntCurveSurface_ThePolyhedronOfHInter, Index: int) -> gp_Pnt: ...
	@staticmethod
	def TriConnex(thePolyh: IntCurveSurface_ThePolyhedronOfHInter, Triang: int, Pivot: int, Pedge: int) -> Tuple[int, int, int]: ...
	@staticmethod
	def Triangle(thePolyh: IntCurveSurface_ThePolyhedronOfHInter, Index: int) -> Tuple[int, int, int]: ...

class IntCurveSurface_TheQuadCurvExactHInter:
	def __init__(self, S: Adaptor3d_HSurface, C: Adaptor3d_HCurve) -> None: ...
	def Intervals(self, Index: int) -> Tuple[float, float]: ...
	def IsDone(self) -> bool: ...
	def NbIntervals(self) -> int: ...
	def NbRoots(self) -> int: ...
	def Root(self, Index: int) -> float: ...

class IntCurveSurface_TheQuadCurvFuncOfTheQuadCurvExactHInter(math_FunctionWithDerivative):
	def __init__(self, Q: IntSurf_Quadric, C: Adaptor3d_HCurve) -> None: ...
	def Derivative(self, Param: float) -> Tuple[bool, float]: ...
	def Value(self, Param: float) -> Tuple[bool, float]: ...
	def Values(self, Param: float) -> Tuple[bool, float, float]: ...

class IntCurveSurface_HInter(IntCurveSurface_Intersection):
	def __init__(self) -> None: ...
	@overload
	def Perform(self, Curve: Adaptor3d_HCurve, Surface: Adaptor3d_HSurface) -> None: ...
	@overload
	def Perform(self, Curve: Adaptor3d_HCurve, Polygon: IntCurveSurface_ThePolygonOfHInter, Surface: Adaptor3d_HSurface) -> None: ...
	@overload
	def Perform(self, Curve: Adaptor3d_HCurve, ThePolygon: IntCurveSurface_ThePolygonOfHInter, Surface: Adaptor3d_HSurface, Polyhedron: IntCurveSurface_ThePolyhedronOfHInter) -> None: ...
	@overload
	def Perform(self, Curve: Adaptor3d_HCurve, ThePolygon: IntCurveSurface_ThePolygonOfHInter, Surface: Adaptor3d_HSurface, Polyhedron: IntCurveSurface_ThePolyhedronOfHInter, BndBSB: Bnd_BoundSortBox) -> None: ...
	@overload
	def Perform(self, Curve: Adaptor3d_HCurve, Surface: Adaptor3d_HSurface, Polyhedron: IntCurveSurface_ThePolyhedronOfHInter) -> None: ...

#classnotwrapped
class IntCurveSurface_ThePolyhedronOfHInter: ...

# harray1 classes
# harray2 classes
# hsequence classes

IntCurveSurface_TheHCurveTool_BSpline = IntCurveSurface_TheHCurveTool.BSpline
IntCurveSurface_TheHCurveTool_Bezier = IntCurveSurface_TheHCurveTool.Bezier
IntCurveSurface_TheHCurveTool_Circle = IntCurveSurface_TheHCurveTool.Circle
IntCurveSurface_TheHCurveTool_Continuity = IntCurveSurface_TheHCurveTool.Continuity
IntCurveSurface_TheHCurveTool_D0 = IntCurveSurface_TheHCurveTool.D0
IntCurveSurface_TheHCurveTool_D1 = IntCurveSurface_TheHCurveTool.D1
IntCurveSurface_TheHCurveTool_D2 = IntCurveSurface_TheHCurveTool.D2
IntCurveSurface_TheHCurveTool_D3 = IntCurveSurface_TheHCurveTool.D3
IntCurveSurface_TheHCurveTool_DN = IntCurveSurface_TheHCurveTool.DN
IntCurveSurface_TheHCurveTool_Ellipse = IntCurveSurface_TheHCurveTool.Ellipse
IntCurveSurface_TheHCurveTool_FirstParameter = IntCurveSurface_TheHCurveTool.FirstParameter
IntCurveSurface_TheHCurveTool_GetType = IntCurveSurface_TheHCurveTool.GetType
IntCurveSurface_TheHCurveTool_Hyperbola = IntCurveSurface_TheHCurveTool.Hyperbola
IntCurveSurface_TheHCurveTool_Intervals = IntCurveSurface_TheHCurveTool.Intervals
IntCurveSurface_TheHCurveTool_IsClosed = IntCurveSurface_TheHCurveTool.IsClosed
IntCurveSurface_TheHCurveTool_IsPeriodic = IntCurveSurface_TheHCurveTool.IsPeriodic
IntCurveSurface_TheHCurveTool_LastParameter = IntCurveSurface_TheHCurveTool.LastParameter
IntCurveSurface_TheHCurveTool_Line = IntCurveSurface_TheHCurveTool.Line
IntCurveSurface_TheHCurveTool_NbIntervals = IntCurveSurface_TheHCurveTool.NbIntervals
IntCurveSurface_TheHCurveTool_NbSamples = IntCurveSurface_TheHCurveTool.NbSamples
IntCurveSurface_TheHCurveTool_Parabola = IntCurveSurface_TheHCurveTool.Parabola
IntCurveSurface_TheHCurveTool_Period = IntCurveSurface_TheHCurveTool.Period
IntCurveSurface_TheHCurveTool_Resolution = IntCurveSurface_TheHCurveTool.Resolution
IntCurveSurface_TheHCurveTool_SamplePars = IntCurveSurface_TheHCurveTool.SamplePars
IntCurveSurface_TheHCurveTool_Value = IntCurveSurface_TheHCurveTool.Value
IntCurveSurface_ThePolygonToolOfHInter_BeginOfSeg = IntCurveSurface_ThePolygonToolOfHInter.BeginOfSeg
IntCurveSurface_ThePolygonToolOfHInter_Bounding = IntCurveSurface_ThePolygonToolOfHInter.Bounding
IntCurveSurface_ThePolygonToolOfHInter_Closed = IntCurveSurface_ThePolygonToolOfHInter.Closed
IntCurveSurface_ThePolygonToolOfHInter_DeflectionOverEstimation = IntCurveSurface_ThePolygonToolOfHInter.DeflectionOverEstimation
IntCurveSurface_ThePolygonToolOfHInter_Dump = IntCurveSurface_ThePolygonToolOfHInter.Dump
IntCurveSurface_ThePolygonToolOfHInter_EndOfSeg = IntCurveSurface_ThePolygonToolOfHInter.EndOfSeg
IntCurveSurface_ThePolygonToolOfHInter_NbSegments = IntCurveSurface_ThePolygonToolOfHInter.NbSegments
IntCurveSurface_ThePolyhedronToolOfHInter_Bounding = IntCurveSurface_ThePolyhedronToolOfHInter.Bounding
IntCurveSurface_ThePolyhedronToolOfHInter_ComponentsBounding = IntCurveSurface_ThePolyhedronToolOfHInter.ComponentsBounding
IntCurveSurface_ThePolyhedronToolOfHInter_DeflectionOverEstimation = IntCurveSurface_ThePolyhedronToolOfHInter.DeflectionOverEstimation
IntCurveSurface_ThePolyhedronToolOfHInter_Dump = IntCurveSurface_ThePolyhedronToolOfHInter.Dump
IntCurveSurface_ThePolyhedronToolOfHInter_GetBorderDeflection = IntCurveSurface_ThePolyhedronToolOfHInter.GetBorderDeflection
IntCurveSurface_ThePolyhedronToolOfHInter_IsOnBound = IntCurveSurface_ThePolyhedronToolOfHInter.IsOnBound
IntCurveSurface_ThePolyhedronToolOfHInter_NbTriangles = IntCurveSurface_ThePolyhedronToolOfHInter.NbTriangles
IntCurveSurface_ThePolyhedronToolOfHInter_Point = IntCurveSurface_ThePolyhedronToolOfHInter.Point
IntCurveSurface_ThePolyhedronToolOfHInter_TriConnex = IntCurveSurface_ThePolyhedronToolOfHInter.TriConnex
IntCurveSurface_ThePolyhedronToolOfHInter_Triangle = IntCurveSurface_ThePolyhedronToolOfHInter.Triangle
